# API reference

::: pycrdt
    options:
      inherited_members: true
      unwrap_annotated: true
      members:
      - BaseType
      - Array
      - ArrayEvent
      - Decoder
      - Doc
      - Map
      - MapEvent
      - NewTransaction
      - ReadTransaction
      - StackItem
      - Subscription
      - SubdocsEvent
      - Text
      - TextEvent
      - Transaction
      - TransactionEvent
      - UndoManager
      - YMessageType
      - YSyncMessageType
      - create_sync_message
      - create_update_message
      - handle_sync_message
      - get_state
      - get_update
      - merge_updates
      - read_message
      - write_var_uint
